use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( examples lib script t xt ) );
__DATA__
Andrew
Chris
Dave
Doran
Etheridge
Felix
Florian
Fredric
Graham
Karen
Kent
Knop
Moore
Ostmann
Prather
Ragwitz
Rodland
Rolsky
Shawn
Tomas
arodland
autarch
autoclean
bobtfish
chris
cpan
ether
haarg
irc
kentfredric
lib
namespace
rafl
sadrak
